@@ -6,6 +6,7 @@ import json
 from sys import *
 import base64
 from prettytable import PrettyTable
+import time
 
 
 
@@ -169,6 +170,7 @@ def run(testrun_id, git_pass, wait_time,env):
             exit(-1)
         project_id=test_data['load_test_details']['project_id']
         test_type=test_data['load_test_details']['test_type']
+        testrun_id_new = test_data['load_test_details']['testrun_id']
         if test_type == 'functional_test':
             sub_link='multi-browser-test'
         elif test_type == 'load_test':
@@ -179,7 +181,7 @@ def run(testrun_id, git_pass, wait_time,env):
             aitest_ui="https://app.aitest.dev.appliedaiconsulting.com/"
         else:
             aitest_ui="https://app.aitest.appliedaiconsulting.com/"
-        testrun_link=aitest_ui+sub_link+"?testrun_id="+testrun_id+"&project_id="+project_id
+        testrun_link=aitest_ui+sub_link+"?testrun_id="+testrun_id_new+"&project_id="+project_id
         click.echo(f"\nTestrun created successfully\nTestrun Name : {test_data['load_test_details']['testrun_name']}\nTestrun ID : {test_data['load_test_details']['testrun_id']}\n")
         click.echo(f"\nTestrun Link: {testrun_link}\n")
         if wait_time:
@@ -196,7 +198,10 @@ def run(testrun_id, git_pass, wait_time,env):
                     base_url = f"https://api.aitest.appliedaiconsulting.com/public/v1/testrun_result/status/{test_data['load_test_details']['testrun_id']}"
                 status_res =requests.get(base_url,headers=headers)
                 status_test_data=status_res.json()
-                if status_test_data['statusCode'] == 200:
+
+                #adding a wait time so that we don't make continuous CALLS to status API.
+                time.sleep(int((wait_time*60)/10))
+                if status_test_data.get("statusCode") and status_test_data['statusCode'] == 200:
                     body=json.loads(status_test_data['body'])
                     test_status = body['testrun_status'] 
                 else:
